<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://ecart.chat
 * @since      1.0.0
 *
 * @package    Abandoned_Cart_For_Woocommerce
 * @subpackage Abandoned_Cart_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Abandoned_Cart_For_Woocommerce
 * @subpackage Abandoned_Cart_For_Woocommerce/admin
 * @author     tradebuk <info@tradebuk.com>
 */
class Abandoned_Cart_For_Woocommerce_Admin {

    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $plugin_name    The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string    $version    The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @since    1.0.0
     * @param      string    $plugin_name       The name of this plugin.
     * @param      string    $version    The version of this plugin.
     */
    public function __construct($plugin_name, $version) {

        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    /**
     * Register the stylesheets for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_styles() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Abandoned_Cart_For_Woocommerce_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Abandoned_Cart_For_Woocommerce_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        $screen = get_current_screen();
        if ('woocommerce_page_abcart-report' == $screen->id) {
            wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/recover-woocommerce-abandoned-cart-admin.css', array(), $this->version, 'all');



            wp_register_style($this->plugin_name . 'bootstrapcss', 'https://maxcdn.bootstrapcdn.com/bootstrap/4.1.3/css/bootstrap.min.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . 'bootstrapcss');

            wp_register_style($this->plugin_name . 'materialdesignicons', 'https://cdnjs.cloudflare.com/ajax/libs/MaterialDesign-Webfont/3.5.95/css/materialdesignicons.css', array(), $this->version, 'all');
            wp_enqueue_style($this->plugin_name . 'materialdesignicons');
        }
    }

    /**
     * Register the JavaScript for the admin area.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {

        /**
         * This function is provided for demonstration purposes only.
         *
         * An instance of this class should be passed to the run() function
         * defined in Abandoned_Cart_For_Woocommerce_Loader as all of the hooks are defined
         * in that particular class.
         *
         * The Abandoned_Cart_For_Woocommerce_Loader will then create the relationship
         * between the defined hooks and the functions defined in this
         * class.
         */
        //Change the hook of this include to admin_footer if need to make an ajax dismiss notice - currently dissmiss will just close the consent banner temporary

        $screen = get_current_screen();
        if ('woocommerce_page_abcart-report' == $screen->id) {

            wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/recover-woocommerce-abandoned-cart-admin.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'chart', plugin_dir_url(__FILE__) . 'js/Chart.min.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'util', plugin_dir_url(__FILE__) . 'js/utils.js', array('jquery'), $this->version, false);

            wp_register_script($this->plugin_name . 'highchartsjs', 'https://code.highcharts.com/highcharts.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'highchartsjs');
            wp_register_script($this->plugin_name . 'highchartsexportjs', 'https://code.highcharts.com/modules/exporting.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'highchartsexportjs');
            wp_register_script($this->plugin_name . 'bootstrapjs', 'https://maxcdn.bootstrapcdn.com/bootstrap/4.1.3/js/bootstrap.min.js', array('jquery'), $this->version, false);
            wp_enqueue_script($this->plugin_name . 'bootstrapjs');
        }
    }

    /**
     * Register product retrieve public API.
     * $id == Product ID
     * @since    1.0.0
     */
    public function add_api_product_route() {
        register_rest_route('abcart/v1', '/product/(?P<id>\d+)', array(
            'methods' => 'GET',
            'callback' => array($this, 'abcart_retrieve_product_details'),
        ));
    }

    /**
     * Retrieve the product details based on specified ID.
     *
     * Function will return the product details in JSON format.
     * @since 1.0.0
     *
     * @param WP_REST_Request $request (int|bool $id) | Product ID | Required.
     * @return JSON Product details - empty [] other wise
     */
    public function abcart_retrieve_product_details(WP_REST_Request $request) {

        $param = $request->get_param('id');

        $produt_data = array();
        if ($param) {

            $product_details = wc_get_product($param);
            if ($product_details) {
                //echo '<re>';print_r($product_details);exit;
                $produt_data['name'] = $product_details->get_name();
                $produt_data['sku'] = $product_details->get_sku();
                $produt_data['regular_price'] = $product_details->get_regular_price();
                $produt_data['sale_price'] = $product_details->get_sale_price();
                $produt_data['total_sales'] = $product_details->get_total_sales();


                wp_send_json(array('data' => $produt_data, 'status' => 'success'));
                exit;
            } else {
                $return = array(
                    'message' => 'No Products with this ID',
                    'status' => 'error'
                );

                wp_send_json($return);
            }
        }

        $return = array(
            'message' => 'Invalid params',
            'status' => 'error'
        );


        /*
        // You can get the combined, merged set of parameters:
        $parameters = $request->get_params();

        // The individual sets of parameters are also available, if needed:
        $parameters = $request->get_url_params();
        $parameters = $request->get_query_params();
        $parameters = $request->get_body_params();
        $parameters = $request->get_json_params();
        $parameters = $request->get_default_params();

        // Uploads aren't merged in, but can be accessed separately:
        $parameters = $request->get_file_params();
        */
    }

    /**
     * Capture the cart and send the information to API.
     * @hook woocommerce_cart_updated
     * @globals mixed $wpdb
     * @globals mixed $woocommerce
     * @since 1.0
     */
    public function abcart_prepare_cart_details($cart_updated = null) {


        global $wpdb, $woocommerce;

        $abcart_allow_consent = get_option('abcart_allow_consent', 'no');

        $shop_id = get_option('abcart_shop_id');

        if ('yes' !== $abcart_allow_consent || false == $shop_id) {
            return;
        }

        $cart = $woocommerce->cart->get_cart();


        if (( isset($_COOKIE['wc_cart_present']) && !($_COOKIE['wc_cart_present'])) && empty($cart)) {
            return;
        }

        if (empty($cart)) {
            setcookie('wc_cart_present', 0, 0, '/', get_site_url());
        } else {
            setcookie('wc_cart_present', 1, 0, '/', get_site_url());
        }


        $status = 'update_cart';
        $payload = $this->prepare_cart_payload($cart, $status);

        $this->send_cart_updated_details($payload);
    }

    public function abcart_prepare_cart_details_order_placed() {

        global $wpdb, $woocommerce;

        $abcart_allow_consent = get_option('abcart_allow_consent', 'no');

        $shop_id = get_option('abcart_shop_id');

        if ('yes' !== $abcart_allow_consent || false == $shop_id) {
            return;
        }

        $cart = $woocommerce->cart->get_cart();

        $status = 'place_cart';
        $payload = $this->prepare_cart_payload($cart, $status);

        $this->send_cart_updated_details($payload);
    }

    public function prepare_cart_payload($cart, $status) {

        global $wpdb, $woocommerce;
        $current_time = current_time('timestamp');

        $payload = array();

        $current_user = wp_get_current_user();
        $user_name = ( $current_user->exists() ) ? $current_user->user_login : '';
        $user_email = ( $current_user->exists() ) ? $current_user->user_email : '';
        $wc_user_id = ( $current_user->exists() ) ? $current_user->ID : '';

        $shop_id = get_option('abcart_shop_id');

        $payload['cart']['customer']['name'] = $user_name;
        $payload['cart']['customer']['email'] = $user_email;
        $payload['cart']['customer']['wc_user_id'] = $wc_user_id;

        $cart_hash_key = apply_filters('woocommerce_cart_hash_key', 'wc_cart_hash_' . md5(get_current_blog_id() . '_' . get_site_url(get_current_blog_id(), '/') . get_template()));

        $cart_hash_key = $woocommerce->session->get_customer_id();  // get for guset session.
        // $cart_hash_key = isset($_COOKIE['wp_woocommerce_session_' . COOKIEHASH]) ? $_COOKIE['wp_woocommerce_session_' . COOKIEHASH] : $cart_hash_key;

        $payload['cart']['customer']['wc_guest_id'] = empty($wc_user_id) ? $cart_hash_key : '';

        $payload['cart']['cart_status'] = $status;


        $payload['cart']['wc_cart']['timestamp'] = $current_time;
        $payload['cart']['wc_cart']['discount_total'] = $woocommerce->cart->get_cart_discount_total();
        $payload['cart']['wc_cart']['shipping_total'] = $woocommerce->cart->shipping_total;
        $payload['cart']['wc_cart']['total_tax'] = $woocommerce->cart->tax_total;
        $payload['cart']['wc_cart']['sub_total'] = $woocommerce->cart->subtotal;
        $payload['cart']['wc_cart']['total'] = $woocommerce->cart->total;

        $carts = array();
        foreach ($cart as $cart_key => $cart_obj) {

            $crt = [];

            $crt['unique_id'] = $cart_obj['key'];
            $crt['timestamp'] = 'timestamp';
            $crt['sub_total'] = $cart_obj['line_subtotal'];
            $crt['total'] = $cart_obj['line_total'];
            $crt['product_id'] = $cart_obj['product_id'];
            $crt['variant_id'] = $cart_obj['variation_id'];
            $crt['quantity'] = $cart_obj['quantity'];
            $crt['name'] = $cart_obj['data']->get_name();
            $crt['price'] = $cart_obj['data']->get_price();
            $crt['image'] = get_the_post_thumbnail_url($cart_obj['product_id']);
            array_push($carts, $crt);
        }
        $payload['cart']['wc_cart']['wc_cart_items'] = $carts;

        $payload['cart']['wc_cart']['digest'] = md5(json_encode($carts, JSON_UNESCAPED_SLASHES));

        return $payload;
    }

    public function send_cart_updated_details($cart_details) {

        // Uncomment below line to block API calls for cart update
        //return;

        $url = ABCART_API_ENDPOINT_BASE . '/carts/update-cart';

        $shop_token = get_option('abcart_shop_token');
        $shop_id = get_option('abcart_shop_id');

        $cart_update_saas_args = apply_filters('cart_update_saas_args', array(
            'method' => 'POST',
            'headers' => array("Content-Type" => "application/json", "Access-Token" => $shop_token, "Shop-ID" => $shop_id),
            'body' => json_encode($cart_details)
                )
        );

        error_log("Before:" . date('l jS \of F Y h:i:s A'));

        $request = wp_remote_post($url, $cart_update_saas_args);

        error_log("After:" . date('l jS \of F Y h:i:s A'));

        if (is_wp_error($request) || wp_remote_retrieve_response_code($request) != 200) {
            return false;
        }
        $response = wp_remote_retrieve_body($request);
        $response_data = json_decode($response);

        // process response data here if need to do anything
    }

    public function abcart_data_usage_consent() {

        $admin_url = get_admin_url();
        echo '<input type="hidden" id="admin_url" value="' . $admin_url . '"/>';
        self::abcart_consent_actions();
        if ('unknown' === get_option('abcart_allow_consent', 'unknown')) :
            ?>
            <div class="abcart-message abcart-consent notice notice-info is-dismissible" style="position: relative;">

                <p class="submit" style="font-size: medium;">
                    <?php _e('Recover WooCommerce Abandon Cart collects your shopping cart update activities and non-sensitive indicative data that helps to recover your abandoned carts.', 'recover-woocommerce-abandoned-cart'); ?></p>
                <a class="button-primary button button-large" href="<?php echo esc_url(wp_nonce_url(add_query_arg('abcart_consent_optin', 'true'), 'abcart_consent_optin', 'abcart_consent_nonce')); ?>"><?php esc_html_e('Got It', ''); ?></a>
                <!--<a class="button-secondary button button-large skip"  href="<?php //echo esc_url(wp_nonce_url(add_query_arg('abcart_consent_optout', 'true'), 'abcart_consent_optout', 'abcart_consent_nonce'));    ?>"><?php //esc_html_e('No thanks', '');    ?></a>-->
            </p>
            </div>
            <?php
        endif;
    }

    private static function abcart_consent_actions() {

        if (isset($_GET['abcart_consent_optin']) && isset($_GET['abcart_consent_nonce']) && wp_verify_nonce($_GET['abcart_consent_nonce'], 'abcart_consent_optin')) {

            // Register SAAS API Token call

            $shop_id = get_option('abcart_shop_id');

            if (FALSE !== $shop_id) {

                $shop_token = get_option('abcart_shop_token');

                if (!$shop_token) {
                    $url = ABCART_API_ENDPOINT_BASE . '/shops/update-token';

                    $t_oken = md5(get_current_blog_id() . '_' . get_site_url(get_current_blog_id(), '/') . get_template() + current_time('timestamp'));

                    $register_store_args = apply_filters('register_saas_token_args', array(
                        'method' => 'POST',
                        'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id),
                        'body' => json_encode(
                                array(
                                    "shop" => array(
                                        "token" => $t_oken
                                    )
                        ))
                            )
                    );



                    $request = wp_remote_post($url, $register_store_args);

                    if (is_wp_error($request) || wp_remote_retrieve_response_code($request) != 200) {
                        return false;
                    }
                    $response = wp_remote_retrieve_body($request);
                    $response_data = json_decode($response);
                }
                update_option('abcart_shop_token', $t_oken);

                update_option('abcart_allow_consent', 'yes');
            }


            header('Location: ' . $_SERVER['HTTP_REFERER']);
        } elseif (isset($_GET['abcart_consent_optout']) && isset($_GET['abcart_consent_nonce']) && wp_verify_nonce($_GET['abcart_consent_nonce'], 'abcart_consent_optout')) {
            update_option('abcart_allow_consent', 'no');
            header('Location: ' . $_SERVER['HTTP_REFERER']);
        }
    }

    public static function abcart_admin_notices() {
        update_option('abcart_allow_consent', 'dismissed');
        die();
    }

    public function register_abandon_cart_report_page() {
        add_submenu_page('woocommerce', 'Abandoned Cart Report', 'Abandoned Cart Report', 'manage_options', 'abcart-report', array($this, 'render_abcart_report_page'));
    }

    public function render_abcart_report_page() {



        $shop_token = get_option('abcart_shop_token');
        $shop_id = get_option('abcart_shop_id');

        if ($shop_token) {
            ?>

            <p></p>
            <h2><span class="badge badge-secondary">Overview</span></h2>
            <?php include 'report-page.php'; ?>


            <?php if ('product' == $current_type): ?>


                <?php
                $ab_products_url = ABCART_API_ENDPOINT_BASE . '/reports/abandon-products';


                $abcart_product_amount = apply_filters('getsaas_cart_product_amount_args', array(
                    'method' => 'POST',
                    'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id, "Access-Token" => $shop_token),
                    'body' => json_encode(
                            array(
                                "report" => array(
                                    "scale" => $current_range,
                                    "graph" => array(
                                        "cart_amount",
                                    )
                                )
                    ))
                        )
                );


                $abcart_product_amount_resp = wp_remote_post($ab_products_url, $abcart_product_amount);

                if (is_wp_error($abcart_product_amount_resp) || wp_remote_retrieve_response_code($abcart_product_amount_resp) != 200) {
                    return false;
                }
                $abcart_product_amount_data = wp_remote_retrieve_body($abcart_product_amount_resp);
                $abcart_product_amount_data = json_decode($abcart_product_amount_data);
                //echo '<pre>';print_r($abcart_product_amount_data);exit;

                if ($abcart_product_amount_data->status == 'failure') {
                    
                    if (!$abcart_product_amount_data->shop_exist){
                        
                        delete_option( 'abcart_shop_id' );
                        delete_option( 'abcart_shop_token' );
                        delete_option( 'abcart_allow_consent' );
                        echo "Something went wrong. Please try again later";
                        return;
                    }
                }

                $amount_graph = $abcart_product_amount_data->data->amount_graph;



                $abcart_product_count = apply_filters('getsaas_cart_product_amount_args', array(
                    'method' => 'POST',
                    'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id, "Access-Token" => $shop_token),
                    'body' => json_encode(
                            array(
                                "report" => array(
                                    "scale" => $current_range,
                                    "graph" => array(
                                        "cart_count",
                                    )
                                )
                    ))
                        )
                );


                $abcart_product_cart_resp = wp_remote_post($ab_products_url, $abcart_product_count);

                if (is_wp_error($abcart_product_cart_resp) || wp_remote_retrieve_response_code($abcart_product_cart_resp) != 200) {
                    return false;
                }
                $abcart_product_cart_data = wp_remote_retrieve_body($abcart_product_cart_resp);
                $abcart_product_cart_data = json_decode($abcart_product_cart_data);

                if ($abcart_product_cart_data->status == 'failure') {
                    echo "Something went wrong. Please try again later";
                    return;
                }

                $count_graph = $abcart_product_cart_data->data->count_graph;


                include 'abandoned-products.php';
                ?>


            <?php else: ?>




                <?php
                $overview_url = ABCART_API_ENDPOINT_BASE . '/reports/dashboard';


                $dashboard_data_section = array(
                    'method' => 'POST',
                    'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id, "Access-Token" => $shop_token),
                    'body' => json_encode(
                            array(
                                "report" => array(
                                    "scale" => $current_range,
                                )
                    ))
                );


                $dashboard_data_resp = wp_remote_post($overview_url, $dashboard_data_section);

                if (is_wp_error($dashboard_data_resp) || wp_remote_retrieve_response_code($dashboard_data_resp) != 200) {
                    return false;
                }
                $dashboard_overview = wp_remote_retrieve_body($dashboard_data_resp);
                $dashboard_overview = json_decode($dashboard_overview);

                if ($dashboard_overview->status == 'failure') {
                    
                    if (!$dashboard_overview->shop_exist){
                        
                        delete_option( 'abcart_shop_id' );
                        delete_option( 'abcart_shop_token' );
                        delete_option( 'abcart_allow_consent' );
                        echo "Something went wrong. Please try again later";
                        return;
                    }
                }

                $today_count = $dashboard_overview->data->today_count;
                $today_amount = $dashboard_overview->data->today_amount;
                $active_count = $dashboard_overview->data->active_count;
                $active_amount = $dashboard_overview->data->active_amount;
                $recent_count = $dashboard_overview->data->recent_count;
                $recent_amount = $dashboard_overview->data->recent_amount;
                $recent_days = $dashboard_overview->data->recent_days;



                $graph_url = ABCART_API_ENDPOINT_BASE . '/reports/graph';

                $current_time = current_time('timestamp');
                $fifteen_days_before = strtotime('-15 days', $current_time);

                $start_date = date('d-m-Y', $fifteen_days_before);
                $end_date = date('d-my-Y', $current_time);


                $cart_amount_query = apply_filters('getsaas_cart_amount_args', array(
                    'method' => 'POST',
                    'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id, "Access-Token" => $shop_token),
                    'body' => json_encode(
                            array(
                                "report" => array(
                                    "scale" => $current_range,
                                    /* 
                                    "period" => "month",
                                    "start_date" => $start_date,
                                    "end_date" => $end_date,
                                    */
                                    "graph" => array(
                                        "cart_amount",
                                    )
                                )
                    ))
                        )
                );



                $cart_amount_data_res = wp_remote_post($graph_url, $cart_amount_query);

                if (is_wp_error($cart_amount_data_res) || wp_remote_retrieve_response_code($cart_amount_data_res) != 200) {
                    return false;
                }
                $cart_amount_response = wp_remote_retrieve_body($cart_amount_data_res);
                $cart_amount_data = json_decode($cart_amount_response);

                if ($cart_amount_data->status == 'failure') {
                    echo "Something went wrong. Please try again later";
                    return;
                }

                $crt_am_graph_details = $cart_amount_data->data->amount_graph;
                $crt_am_graphdata = $crt_am_graph_details->graph_data;

                $crt_am_graphdata_keys = array_keys((array) $crt_am_graphdata);

                $crt_am_graphdata_values = array_values((array) $crt_am_graphdata);

                $crt_am_total = $crt_am_graph_details->total_amount;


                $cart_count_query = apply_filters('getsaas_cart_count_args', array(
                    'method' => 'POST',
                    'headers' => array("Content-Type" => "application/json", "Shop-Id" => $shop_id, "Access-Token" => $shop_token),
                    'body' => json_encode(
                            array(
                                "report" => array(
                                    "scale" => $current_range,
                                    /*
                                    "start_date" => $start_date,
                                    "end_date" => $end_date,
                                    */
                                    "graph" => array(
                                        "cart_count",
                                    )
                                )
                    ))
                        )
                );



                $cart_count_data_res = wp_remote_post($graph_url, $cart_count_query);

                if (is_wp_error($cart_count_data_res) || wp_remote_retrieve_response_code($cart_count_data_res) != 200) {
                    return false;
                }
                $cart_count_response = wp_remote_retrieve_body($cart_count_data_res);
                $cart_count_data = json_decode($cart_count_response);


                $crt_cn_graph_details = $cart_count_data->data->count_graph;
                $crt_cn_graphdata = $crt_cn_graph_details->graph_data;
                $crt_cn_graphdata_keys = array_keys((array) $crt_cn_graphdata);

                $crt_cn_graphdata_values = array_values((array) $crt_cn_graphdata);
                $crt_cn_total = $crt_cn_graph_details->total_count;
                ?>



                <style>
                    canvas{
                        -moz-user-select: none;
                        -webkit-user-select: none;
                        -ms-user-select: none;
                    }
                </style>


                <div class="row"><p></p></div>
                <div class="container">



                    <div class="row">
                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cart text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right">Abandoned Cart Value</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo get_woocommerce_currency_symbol(), $recent_amount; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <p class="text-muted mt-3 mb-0">
                                        <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> Last <?php echo $recent_days, ($recent_days == 1) ? ' day' : ' days'; ?>
                                    </p>
                                </div>
                            </div>
                        </div>


                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cart-plus text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right">Abandoned Cart Count</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo $recent_count; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <p class="text-muted mt-3 mb-0">
                                        <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> Last <?php echo $recent_days, ($recent_days == 1) ? ' day' : ' days'; ?>
                                    </p>
                                </div>
                            </div>
                        </div>


                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cart-outline text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right">Active Cart Value</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo get_woocommerce_currency_symbol(), $active_amount; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <!--<p class="text-muted mt-3 mb-0">
                                      <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> 65% lower growth 
                                    </p>-->
                                </div>
                            </div>
                        </div>


                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cart-arrow-right text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right">Active Cart Count</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo $active_count; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <!--<p class="text-muted mt-3 mb-0">
                                      <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> 65% lower growth 
                                    </p>-->
                                </div>
                            </div>
                        </div>


                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cart-arrow-up text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right"> Cart Value(Today)</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo get_woocommerce_currency_symbol(), $today_amount; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <!--<p class="text-muted mt-3 mb-0">
                                      <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> 65% lower growth 
                                    </p>-->
                                </div>
                            </div>
                        </div>



                        <div class="col-xl-3 col-lg-3 col-md-3 col-sm-6 grid-margin stretch-card">
                            <div class="card card-statistics">
                                <div class="card-body">
                                    <div class="clearfix">
                                        <div class="float-left">
                                            <i class="mdi mdi-cube text-danger icon-lg mdi-36px"></i>
                                        </div>
                                        <div class="float-right">
                                            <p class="mb-0 text-right">Cart Count(Today)</p>
                                            <div class="fluid-container">
                                                <h3 class="font-weight-medium text-right mb-0"><?php echo $today_count; ?></h3>
                                            </div>
                                        </div>
                                    </div>
                                    <!--<p class="text-muted mt-3 mb-0">
                                      <i class="mdi mdi-alert-octagon mr-1" aria-hidden="true"></i> 65% lower growth 
                                    </p>-->
                                </div>
                            </div>
                        </div>

                    </div>


                </div>
                <br/>



                <div style="width:95%;">
                    <canvas id="canvas1"></canvas>
                </div>
                <br>

                <script>

                    var MONTHS = <?php echo json_encode($crt_cn_graphdata_keys); ?>;
                    var config = {
                        type: 'line',
                        data: {
                            labels: <?php echo json_encode($crt_cn_graphdata_keys); ?>,
                            datasets: [

                                {
                                    label: 'Cart Count Data',
                                    fill: false,
                                    backgroundColor: window.chartColors.blue,
                                    borderColor: window.chartColors.blue,
                                    data: <?php echo json_encode($crt_cn_graphdata_values); ?>,
                                }
                            ]
                        },
                        options: {
                            responsive: true,
                            title: {
                                display: true,
                                text: 'Cart Count Details'
                            },
                            tooltips: {
                                mode: 'index',
                                intersect: false,
                            },
                            hover: {
                                mode: 'nearest',
                                intersect: true
                            },
                            scales: {
                                xAxes: [{
                                        display: true,
                                        scaleLabel: {
                                            display: true,
                                            labelString: '<?php echo ucwords($current_range); ?>'
                                        }
                                    }],
                                yAxes: [{
                                        display: true,
                                        scaleLabel: {
                                            display: true,
                                            labelString: 'Value'
                                        }
                                    }]
                            }
                        }
                    };



                    var config2 = {
                        type: 'line',
                        data: {
                            labels: <?php echo json_encode($crt_am_graphdata_keys); ?>,
                            datasets: [

                                {
                                    label: 'Cart Amount Data',
                                    fill: false,
                                    backgroundColor: window.chartColors.blue,
                                    borderColor: window.chartColors.blue,
                                    data:<?php echo json_encode($crt_am_graphdata_values); ?>,
                                }
                            ]
                        },
                        options: {
                            responsive: true,
                            title: {
                                display: true,
                                text: 'Cart Amount Details'
                            },
                            tooltips: {
                                mode: 'index',
                                intersect: false,
                            },
                            hover: {
                                mode: 'nearest',
                                intersect: true
                            },
                            scales: {
                                xAxes: [{
                                        display: true,
                                        scaleLabel: {
                                            display: true,
                                            labelString: '<?php echo ucwords($current_range); ?>'
                                        }
                                    }],
                                yAxes: [{
                                        display: true,
                                        scaleLabel: {
                                            display: true,
                                            labelString: 'Value'
                                        }
                                    }]
                            }
                        }
                    };


                    window.onload = function () {

                        var ctx = document.getElementById('canvas1').getContext('2d');
                        window.myLine = new Chart(ctx, config);

                        var ctx2 = document.getElementById('canvas2').getContext('2d');
                        window.myLine = new Chart(ctx2, config2);
                    };

                </script>


                <div style="width:95%;">
                    <canvas id="canvas2"></canvas>
                </div>

            <?php endif; ?>

            <?php
        } else {
            ?>
                

            <div class="abcart-message abcart-consent notice notice-info is-dismissible" style="position: relative;">

                <p class="submit" style="font-size: medium;">
                    <?php _e('Please click on the above button to give consent and to display dashboard contents properly. ', 'recover-woocommerce-abandoned-cart'); ?>
                </p>
            </div>
                
                <?php
            
        }
    }

    public function abcart_plugin_action_links($links) {

        $plugin_links = array(
            '<a href="' . admin_url('admin.php?page=abcart-report') . '">' . __('Abandoned Cart Report', 'recover-woocommerce-abandoned-cart') . '</a>',
            '<a target="_blank" href="https://wordpress.org/support/plugin/recover-woocommerce-abandoned-cart/">' . __('Support', 'recover-woocommerce-abandoned-cart') . '</a>',
            '<a target="_blank" href="https://wordpress.org/support/plugin/recover-woocommerce-abandoned-cart/reviews/">' . __('Review', 'recover-woocommerce-abandoned-cart') . '</a>',
        );
        if (array_key_exists('deactivate', $links)) {
            $links['deactivate'] = str_replace('<a', '<a class="abcartdeactivate-link"', $links['deactivate']);
        }
        return array_merge($plugin_links, $links);
    }

}
